@@ -111,21 +111,41 @@ L.Storage.on('ui:alert', function (e) {
 /*
 * Tooltips
 */
-L.Storage.on('ui:tooltip', function (e) {
-    var div = L.DomUtil.get('storage-tooltip-container');
-    var body = document.getElementsByTagName('body')[0];
-    div.innerHTML = '';
-    div.innerHTML = e.content;
-    L.DomUtil.addClass(body, 'storage-tooltip');
-    var map = L.DomUtil.get('map'),
-        left = map.offsetLeft + (map.clientWidth / 2) - (div.clientWidth / 2),
-        top = map.offsetTop + 5,
-        point = L.point(left, top);
-    L.DomUtil.setPosition(div, point);
-    var close = function () {
-        div.innerHTML = '';
-        L.DomUtil.removeClass(body, 'storage-tooltip');
+L.Storage.on('ui:tooltip:init', function (e) {
+    var tooltip = L.DomUtil.get('storage-tooltip-container'),
+        map = e.map,
+        ID;
+
+    var close = function (id) {
+        if (id && id !== ID) return;
+        tooltip.innerHTML = '';
+        L.DomUtil.removeClass(document.body, 'storage-tooltip');
     };
-    L.DomEvent.on(div, 'mouseover', close);
-    window.setTimeout(close, 3000);
+
+    var setFixedPosition = function () {
+        var left = map._container.offsetLeft + (map._container.clientWidth / 2) - (tooltip.clientWidth / 2),
+            top = map._container.offsetTop + 5,
+            point = L.point(left, top);
+        L.DomUtil.setPosition(tooltip, point);
+    };
+
+    L.Storage.on('ui:tooltip', function (e) {
+        ID = Math.random();
+        var id = ID;
+        L.DomUtil.addClass(document.body, 'storage-tooltip');
+        setFixedPosition();
+        tooltip.innerHTML = e.content;
+        function closeIt () {close(id);}
+        if (e.attachTo) {
+            L.DomEvent.on(e.attachTo, 'mouseout', closeIt);
+        }
+        if (e.duration !== Infinity) {
+            window.setTimeout(closeIt, e.duration || 3000);
+        }
+    });
+
+    L.Storage.on('ui:tooltip:abort', function () {
+        close();
+    });
+
 });
