@@ -111,20 +111,30 @@ L.Editable = L.Class.extend({
         this.unregisterForDrawing();
     },
 
-    startPolyline: function () {
+    startPolyline: function (latlng) {
         var line = this.createPolyline([]).connectCreatedToMap(this.map),
             editor = line.enableEdit();
         editor.startDrawingForward();
+        if (latlng) editor.newPointForward(latlng);
         return line;
     },
 
-    startPolygon: function () {
+    startPolygon: function (latlng) {
         var polygon = this.createPolygon([]).connectCreatedToMap(this.map),
             editor = polygon.enableEdit();
         editor.startDrawingForward();
+        if (latlng) editor.newPointForward(latlng);
         return polygon;
     },
 
+    startMarker: function (latlng) {
+        latlng = latlng || this.map.getCenter();
+        var marker = this.createMarker(latlng).connectCreatedToMap(this.map),
+            editor = marker.enableEdit();
+        editor.startDrawing();
+        return marker;
+    },
+
     startHole: function (editor, latlng) {
         editor.newHole(latlng);
     },
@@ -138,14 +148,6 @@ L.Editable = L.Class.extend({
         return polygon;
     },
 
-    startMarker: function (latlng) {
-        latlng = latlng || this.map.getCenter();
-        var marker = this.createMarker(latlng).connectCreatedToMap(this.map),
-            editor = marker.enableEdit();
-        editor.startDrawing();
-        return marker;
-    },
-
     createPolyline: function (latlngs) {
         var line = new this.options.polylineClass(latlngs);
         this.map.fire('editable:created', {layer: line});
@@ -198,7 +200,7 @@ L.Editable.VertexMarker = L.Marker.extend({
     options: {
         draggable: true,
         riseOnOver: true,
-        zIndex: 10001,
+        zIndexOffset: 100,
         className: 'leaflet-div-icon leaflet-vertex-icon'
     },
 
@@ -326,7 +328,6 @@ L.Editable.mergeOptions({
 L.Editable.MiddleMarker = L.Marker.extend({
 
     options: {
-        zIndex: 10000,
         opacity: 0.5,
         className: 'leaflet-div-icon leaflet-middle-icon'
     },
@@ -404,10 +405,12 @@ L.Editable.BaseEditor = L.Class.extend({
         this.tools.editLayer.addLayer(this.editLayer);
         this.onEnable();
         this._enabled = true;
+        this.feature.on('remove', this.disable, this);
         return this;
     },
 
     disable: function () {
+        this.feature.off('remove', this.disable, this);
         this.editLayer.clearLayers();
         this.tools.editLayer.removeLayer(this.editLayer);
         this.onDisable();
@@ -448,8 +451,8 @@ L.Editable.BaseEditor = L.Class.extend({
         this._fireAndForward('editable:drawing:cancel');
     },
 
-    onFinishDrawing: function () {
-        this._fireAndForward('editable:drawing:finish');
+    onCommitDrawing: function () {
+        this._fireAndForward('editable:drawing:commit');
     },
 
     startDrawing: function () {
@@ -458,14 +461,14 @@ L.Editable.BaseEditor = L.Class.extend({
         this.onStartDrawing();
     },
 
-    finishDrawing: function () {
+    commitDrawing: function () {
+        this.onCommitDrawing();
         this.endDrawing();
-        this.onFinishDrawing();
     },
 
     cancelDrawing: function () {
-        this.endDrawing();
         this.onCancelDrawing();
+        this.endDrawing();
     },
 
     endDrawing: function () {
@@ -486,9 +489,7 @@ L.Editable.BaseEditor = L.Class.extend({
     },
 
     onNewClickHandlerClicked: function (e) {
-        if (!this.isNewClickValid(e.latlng)) return;
         this._fireAndForward('editable:drawing:click', e);
-        return true;
     },
 
     isNewClickValid: function (latlng) {
@@ -522,8 +523,10 @@ L.Editable.MarkerEditor = L.Editable.BaseEditor.extend({
     },
 
     onNewClickHandlerClicked: function (e) {
-        if (!L.Editable.BaseEditor.prototype.onNewClickHandlerClicked.call(this, e)) return;
-        this.finishDrawing();
+        if (!this.isNewClickValid(e.latlng)) return;
+        // Send event before finishing drawing
+        L.Editable.BaseEditor.prototype.onNewClickHandlerClicked.call(this, e);
+        this.commitDrawing();
     }
 
 });
@@ -542,7 +545,7 @@ L.Editable.PathEditor = L.Editable.BaseEditor.extend({
     },
 
     disable: function () {
-        L.Editable.BaseEditor.prototype.disable.call(this);
+        return L.Editable.BaseEditor.prototype.disable.call(this);
     },
 
     initVertexMarkers: function () {
@@ -590,11 +593,11 @@ L.Editable.PathEditor = L.Editable.BaseEditor.extend({
         } else if (e.originalEvent.shiftKey) {
             this.onVertexMarkerShiftClick(e);
         } else if (index >= 1 && index === e.vertex.getLastIndex() && this.drawing === L.Editable.FORWARD) {
-            this.finishDrawing();
+            this.commitDrawing();
         } else if (index === 0 && this.drawing === L.Editable.BACKWARD && this._drawnLatLngs.length >= this.MIN_VERTEX) {
-            this.finishDrawing();
+            this.commitDrawing();
         } else if (index === 0 && this.drawing === L.Editable.FORWARD && this._drawnLatLngs.length >= this.MIN_VERTEX && this.CLOSED) {
-            this.finishDrawing();  // Allow to close on first point also for polygons
+            this.commitDrawing();  // Allow to close on first point also for polygons
         } else {
             this.onVertexRawMarkerClick(e);
         }
@@ -676,9 +679,10 @@ L.Editable.PathEditor = L.Editable.BaseEditor.extend({
     },
 
     onNewClickHandlerClicked: function (e) {
-        if (!L.Editable.BaseEditor.prototype.onNewClickHandlerClicked.call(this, e)) return;
+        if (!this.isNewClickValid(e.latlng)) return;
         if (this.drawing === L.Editable.FORWARD) this.newPointForward(e.latlng);
         else this.newPointBackward(e.latlng);
+        L.Editable.BaseEditor.prototype.onNewClickHandlerClicked.call(this, e);
     },
 
     onMouseMove: function (e) {
@@ -805,7 +809,6 @@ var EditableMixin = {
     enableEdit: function () {
         if (!this.editor) {
             this.createEditor();
-            this.on('remove', this.disableEdit);
         }
         return this.editor.enable();
     },
@@ -817,13 +820,12 @@ var EditableMixin = {
     disableEdit: function () {
         if (this.editor) {
             this.editor.disable();
-            this.off('remove', this.disableEdit);
             delete this.editor;
         }
     },
 
     toggleEdit: function () {
-      if (this.editor) {
+      if (this.editEnabled()) {
         this.disableEdit();
       } else {
         this.enableEdit();
